#!/bin/bash

# Source for trac-spamfilter-plugin comes from SVN repository at svn.edgewall.com
site=http://svn.edgewall.com/
repo=repos/trac/plugins
svnname=spam-filter
tarname=TracSpamFilter

# Specify the branch and revision we're after, plus the version upstream calls itself
branch=1.0
svnrel=13942
version=1.0.6

# Pull the desired version from svn
svn checkout -r ${svnrel} ${site}${repo}/${branch}/${svnname} ${tarname}-${version}

# Make timestamps be that of last upstream change
find ${tarname}-${version} -name .svn -prune -o -print |
while read pathname
do
	timestamp=$(svn info ${pathname} | awk '/^Last Changed Date:/ { print $4 " " $5 " " $6 }')
	touch --date="${timestamp}" ${pathname}
done

# Make a tarball
cd ${tarname}-${version}
python setup.py sdist --formats bztar
# Work around svn 1.0 incompatibility (http://trac.edgewall.org/ticket/10658)
if [ ! -f dist/${tarname}-${version}dev-r${svnrel}.tar.bz2 -a -f dist/${tarname}-${version}dev-r0.tar.bz2 ]; then
	tar xfj dist/${tarname}-${version}dev-r0.tar.bz2
	rm dist/${tarname}-${version}dev-r0.tar.bz2
	grep -rl dev-r0 ${tarname}-${version}dev-r0 | xargs sed -i -e "s/dev-r0/dev-r${svnrel}/"
	mv ${tarname}-${version}dev-r0 ${tarname}-${version}dev-r${svnrel}
	tar cfj dist/${tarname}-${version}dev-r${svnrel}.tar.bz2 ${tarname}-${version}dev-r${svnrel}
fi
cd -
mv ${tarname}-${version}/dist/${tarname}-${version}dev-r${svnrel}.tar.bz2 .
# Set time of tarball to time of last commit
timestamp=$(svn info ${tarname}-${version} | awk '/^Last Changed Date:/ { print $4 " " $5 " " $6 }')
touch --date="${timestamp}" ${tarname}-${version}dev-r${svnrel}.tar.bz2

# Display checkout status
svn info ${tarname}-${version} | grep "Last Changed"

# Remove the svn checkout
rm -rf ${tarname}-${version}
